==> sds-styling-hooks-0.2.2.tgz: package/lib/components/Example.js <==
export class Example extends HTMLElement {
  constructor() {
    super();
    const shadow = this.attachShadow({ mode: 'open' });
    shadow.innerHTML = `
      <dl>
        <dt>Value</dt>
        <dd class="value"></dd>
        <dt>Styling Hook</dt>
        <dd class="prop"></dd>
        <dt>Example</dt>
        <dd class="example"><slot></slot></dd>
      </dl>
      <style>
        dl {
          display: flex;
          flex-direction: column;
          border-bottom: 1px solid rgba(0,0,0,.15);
          padding: 1rem;
        }
        dt {
          color: rgba(0,0,0,.5);
          font-size: 0.825rem;
          font-weight: bold;
          margin-bottom: 0.125rem;
        }
        dd {
          margin: 0 0 0.5rem;
        }
        code {
          padding: 0.2em 0.4em;
          margin: 0;
          background-color: rgba(27, 31, 35, 0.05);
          border-radius: 6px;
          white-space: pre-wrap;
        }
        :host([category="border-radius"]) .example {
          width: 50px;
          height: 50px;
          background: #0176d3;
        }
      </style>
    `;
  }

  get value() {
    return this.getAttribute('value');
  }

  get prop() {
    return this.getAttribute('prop');
  }

  get category() {
    return this.getAttribute('category');
  }

  connectedCallback() {
    const prop = this.shadowRoot.querySelector('.prop');
    const value = this.shadowRoot.querySelector('.value');
    const example = this.shadowRoot.querySelector('.example');
    if (this.hasAttribute('value')) {
      value.innerHTML = `${this.value}`;
      example.setAttribute('style', `${this.category}: ${this.value};`);
    }
    if (this.hasAttribute('prop')) {
      prop.innerHTML = `<code>${this.prop}</code>`;
    }
  }
}

==> sds-styling-hooks-0.3.0.tgz: package/lib/components/Example.js <==
export class Example extends HTMLElement {
  constructor() {
    super();
    const shadow = this.attachShadow({ mode: 'open' });
    shadow.innerHTML = `
      <dl>
        <dt>Value</dt>
        <dd class="value"></dd>
        <dt>Styling Hook</dt>
        <dd class="prop"></dd>
        <dt>Example</dt>
        <dd class="example"><slot></slot></dd>
      </dl>
      <style>
        dl {
          display: flex;
          flex-direction: column;
          border-bottom: 1px solid rgba(0,0,0,.15);
          padding: 1rem;
        }
        dt {
          color: rgba(0,0,0,.5);
          font-size: 0.825rem;
          font-weight: bold;
          margin-bottom: 0.125rem;
        }
        dd {
          margin: 0 0 0.5rem;
        }
        code {
          padding: 0.2em 0.4em;
          margin: 0;
          background-color: rgba(27, 31, 35, 0.05);
          border-radius: 6px;
          white-space: pre-wrap;
        }
        :host([category="border-radius"]) .example {
          width: 50px;
          height: 50px;
          background: #0176d3;
        }
        :host([category="shadow"]) .example {
          width: 150px;
          height: 150px;
          background: white;
        }
        :host([category="spacing"]) .example {
          width: 0;
          height: 0;
          background: #0176d3;
        }
      </style>
    `;
  }

  get value() {
    return this.getAttribute('value');
  }

  get prop() {
    return this.getAttribute('prop');
  }

  get category() {
    return this.getAttribute('category');
  }

  get cssProperty() {
    const prop = this.getAttribute('cssProperty');
    if (this.category === 'spacing') {
      return `padding-top: ${this.value}; padding-left`;
    }
    return prop;
  }

  connectedCallback() {
    const prop = this.shadowRoot.querySelector('.prop');
    const value = this.shadowRoot.querySelector('.value');
    const example = this.shadowRoot.querySelector('.example');
    if (this.hasAttribute('value')) {
      value.innerHTML = `<code>${this.value}</code>`;
      example.setAttribute('style', `${this.cssProperty}: ${this.value};`);
    }
    if (this.hasAttribute('prop')) {
      prop.innerHTML = `<code>${this.prop}</code>`;
    }
  }
}
